var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import _ from 'lodash';
import React from 'react';
import moment from 'moment';
import { Form, Input, Select, InputNumber, DatePicker, Radio } from 'antd';
import InputStyle from './Constants/InputStyle';
import MoneyInput from './MoneyInput';

var Option = Select.Option;
var RangePicker = DatePicker.RangePicker;


export default function RenderField(field, form, data) {
  var inputProps = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var renderExtra = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
  var state = arguments[5];
  var handlers = arguments[6];

  var defaultValue = null;
  var getFieldDecorator = form.getFieldDecorator;

  switch (field.InputStyle) {
    case InputStyle.Input:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        React.createElement(
          'div',
          { hidden: !field.DisplayOnly },
          defaultValue
        ),
        React.createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(React.createElement(Input, _extends({ placeholder: field.PlaceHolder }, inputProps)))
        )
      );
    case InputStyle.InputNumber:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      var formatter = function formatter(value) {
        return '' + (field.Payload.Prefix ? field.Payload.Prefix + ' ' : '') + value + (field.Payload.Suffix ? ' ' + field.Payload.Suffix : '');
      };
      var parser = function parser(value) {
        var ret = value;
        if (field.Payload.Prefix) ret = value.replace(field.Payload.Prefix + ' ', '');
        if (field.Payload.Suffix) ret = value.replace(' ' + field.Payload.Suffix, '');
        return ret;
      };
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        React.createElement(
          'div',
          { hidden: !field.DisplayOnly },
          formatter(defaultValue)
        ),
        React.createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(React.createElement(InputNumber, _extends({
            formatter: formatter,
            parser: parser,
            style: { width: '100%' },
            disabled: field.Disabled
          }, inputProps)))
        )
      );
    case InputStyle.Select:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue === null ? undefined : defaultValue;

      var defaultValues = _.isArray(defaultValue) ? defaultValue : [defaultValue];
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        React.createElement(
          'div',
          { hidden: !field.DisplayOnly, style: { minHeight: 39.2 } },
          _.filter(field.Payload.Options, function (o) {
            return _.includes(defaultValues, o.Value);
          }).map(function (o) {
            return o.Display;
          }).join(", ")
        ),
        React.createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(React.createElement(
            Select,
            _extends({
              className: 'formcore_select',
              mode: field.Payload.Mode,
              style: { width: '100%' },
              tokenSeparators: field.Payload.TokenSeparators
            }, inputProps),
            _.map(field.Payload.Options, function (option) {
              return React.createElement(
                Option,
                { key: option.Value, value: option.Value },
                option.Display
              );
            })
          ))
        )
      );
    case InputStyle.DatePicker:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue ? moment(defaultValue).local() : null;
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(React.createElement(DatePicker, { style: { width: '100%' } }))
      );
    case InputStyle.InfiniteOrFixedDateRadioGroup:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue || "fixed";
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label },
        React.createElement(
          Radio.Group,
          {
            defaultValue: defaultValue,
            onChange: handlers.handleExpiredAtTypeChange
          },
          React.createElement(
            Radio.Button,
            { value: 'fixed' },
            'Fixed'
          ),
          React.createElement(
            Radio.Button,
            { value: 'indefinite' },
            'Indefinite'
          )
        )
      );
    case InputStyle.InfiniteOrFixedDateDatePicker:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue ? moment(defaultValue).local() : null;
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label },
        getFieldDecorator('ExpiredAt', {
          initialValue: defaultValue
        })(React.createElement(DatePicker, {
          style: { width: '100%' },
          disabled: state.expiredAtType === 'indefinite'
        }))
      );
    case InputStyle.RangePicker:
      if (data) {
        defaultValue = data[field.Column];
      } else {
        defaultValue = !field.DefaultValue ? null : field.DefaultValue.map(function (x) {
          return x ? moment(x) : null;
        });
      }
      if (defaultValue && !defaultValue[0] && defaultValue[1]) {
        var _defaultValue = defaultValue;
        defaultValue[0] = _defaultValue[1];
      }
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(React.createElement(RangePicker, _extends({
          disabledDate: function disabledDate(current) {
            var MinStartedAt = _.get(field, 'Payload.MinStartedAt', null);
            return current && current < MinStartedAt;
          },
          placeholder: field.PlaceHolder,
          style: { width: '100%' }
        }, inputProps)))
      );
    case InputStyle.RangeLatterHalfPicker:
      var ph = _.split(field.PlaceHolder, ",");
      defaultValue = data[field.Column];
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        React.createElement(
          'span',
          { hidden: field.DisplayOnly },
          defaultValue[0].format('YYYY-MM-DD') + " ~ "
        ),
        React.createElement(
          'span',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {})(React.createElement(DatePicker, _extends({ disabledDate: function disabledDate(current) {
              var MinExpiredAt = _.get(field, 'Payload.MinExpiredAt', null);
              return current && current < MinExpiredAt;
            },
            placeholder: ph[1],
            style: { width: '50%' } }, inputProps)))
        )
      );
    case InputStyle.Hidden:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(React.createElement(Input, _extends({
          disabled: true,
          placeholder: field.PlaceHolder,
          style: { display: 'none' }
        }, inputProps)))
      );
    case InputStyle.MoneyInput:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        React.createElement(
          'div',
          { hidden: !field.DisplayOnly },
          '$ ' + defaultValue
        ),
        React.createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(React.createElement(MoneyInput, _extends({ style: { width: '100%' }, placeholder: field.PlaceHolder }, inputProps)))
        )
      );
    case InputStyle.DisplayOnly:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return React.createElement(
        Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(React.createElement(Input, _extends({
          disabled: true,
          className: 'formcore_display-only-input',
          style: { width: '100%' },
          placeholder: field.PlaceHolder
        }, inputProps)))
      );
    default:
      if (renderExtra) {
        return renderExtra(field, form, data, inputProps);
      }
      throw new Error('FormCore: Unspported input style ' + field.InputStyle + ' of field ' + field.Id + '. You might want to consider using customized input styles, cf. the renderExtra parameter. Otheriwse pull Requests are welcome: https://github.com/pmq20/FormCore/pulls');
  }
}