'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports['default'] = RenderField;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _antd = require('antd');

var _InputStyle = require('./Constants/InputStyle');

var _InputStyle2 = _interopRequireDefault(_InputStyle);

var _MoneyInput = require('./MoneyInput');

var _MoneyInput2 = _interopRequireDefault(_MoneyInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var Option = _antd.Select.Option;
var RangePicker = _antd.DatePicker.RangePicker;
function RenderField(field, form, data) {
  var inputProps = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  var renderExtra = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
  var state = arguments[5];
  var handlers = arguments[6];

  var defaultValue = null;
  var getFieldDecorator = form.getFieldDecorator;

  switch (field.InputStyle) {
    case _InputStyle2['default'].Input:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        _react2['default'].createElement(
          'div',
          { hidden: !field.DisplayOnly },
          defaultValue
        ),
        _react2['default'].createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(_react2['default'].createElement(_antd.Input, _extends({ placeholder: field.PlaceHolder }, inputProps)))
        )
      );
    case _InputStyle2['default'].InputNumber:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      var formatter = function formatter(value) {
        return '' + (field.Payload.Prefix ? field.Payload.Prefix + ' ' : '') + value + (field.Payload.Suffix ? ' ' + field.Payload.Suffix : '');
      };
      var parser = function parser(value) {
        var ret = value;
        if (field.Payload.Prefix) ret = value.replace(field.Payload.Prefix + ' ', '');
        if (field.Payload.Suffix) ret = value.replace(' ' + field.Payload.Suffix, '');
        return ret;
      };
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        _react2['default'].createElement(
          'div',
          { hidden: !field.DisplayOnly },
          formatter(defaultValue)
        ),
        _react2['default'].createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(_react2['default'].createElement(_antd.InputNumber, _extends({
            formatter: formatter,
            parser: parser,
            style: { width: '100%' },
            disabled: field.Disabled
          }, inputProps)))
        )
      );
    case _InputStyle2['default'].Select:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue === null ? undefined : defaultValue;

      var defaultValues = _lodash2['default'].isArray(defaultValue) ? defaultValue : [defaultValue];
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        _react2['default'].createElement(
          'div',
          { hidden: !field.DisplayOnly, style: { minHeight: 39.2 } },
          _lodash2['default'].filter(field.Payload.Options, function (o) {
            return _lodash2['default'].includes(defaultValues, o.Value);
          }).map(function (o) {
            return o.Display;
          }).join(", ")
        ),
        _react2['default'].createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(_react2['default'].createElement(
            _antd.Select,
            _extends({
              className: 'formcore_select',
              mode: field.Payload.Mode,
              style: { width: '100%' },
              tokenSeparators: field.Payload.TokenSeparators
            }, inputProps),
            _lodash2['default'].map(field.Payload.Options, function (option) {
              return _react2['default'].createElement(
                Option,
                { key: option.Value, value: option.Value },
                option.Display
              );
            })
          ))
        )
      );
    case _InputStyle2['default'].DatePicker:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue ? (0, _moment2['default'])(defaultValue).local() : null;
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(_react2['default'].createElement(_antd.DatePicker, { style: { width: '100%' } }))
      );
    case _InputStyle2['default'].InfiniteOrFixedDateRadioGroup:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue || "fixed";
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label },
        _react2['default'].createElement(
          _antd.Radio.Group,
          {
            defaultValue: defaultValue,
            onChange: handlers.handleExpiredAtTypeChange
          },
          _react2['default'].createElement(
            _antd.Radio.Button,
            { value: 'fixed' },
            'Fixed'
          ),
          _react2['default'].createElement(
            _antd.Radio.Button,
            { value: 'indefinite' },
            'Indefinite'
          )
        )
      );
    case _InputStyle2['default'].InfiniteOrFixedDateDatePicker:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      defaultValue = defaultValue ? (0, _moment2['default'])(defaultValue).local() : null;
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label },
        getFieldDecorator('ExpiredAt', {
          initialValue: defaultValue
        })(_react2['default'].createElement(_antd.DatePicker, {
          style: { width: '100%' },
          disabled: state.expiredAtType === 'indefinite'
        }))
      );
    case _InputStyle2['default'].RangePicker:
      if (data) {
        defaultValue = data[field.Column];
      } else {
        defaultValue = !field.DefaultValue ? null : field.DefaultValue.map(function (x) {
          return x ? (0, _moment2['default'])(x) : null;
        });
      }
      if (defaultValue && !defaultValue[0] && defaultValue[1]) {
        var _defaultValue = defaultValue;
        defaultValue[0] = _defaultValue[1];
      }
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(_react2['default'].createElement(RangePicker, _extends({
          disabledDate: function disabledDate(current) {
            var MinStartedAt = _lodash2['default'].get(field, 'Payload.MinStartedAt', null);
            return current && current < MinStartedAt;
          },
          placeholder: field.PlaceHolder,
          style: { width: '100%' }
        }, inputProps)))
      );
    case _InputStyle2['default'].RangeLatterHalfPicker:
      var ph = _lodash2['default'].split(field.PlaceHolder, ",");
      defaultValue = data[field.Column];
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        _react2['default'].createElement(
          'span',
          { hidden: field.DisplayOnly },
          defaultValue[0].format('YYYY-MM-DD') + " ~ "
        ),
        _react2['default'].createElement(
          'span',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {})(_react2['default'].createElement(_antd.DatePicker, _extends({ disabledDate: function disabledDate(current) {
              var MinExpiredAt = _lodash2['default'].get(field, 'Payload.MinExpiredAt', null);
              return current && current < MinExpiredAt;
            },
            placeholder: ph[1],
            style: { width: '50%' } }, inputProps)))
        )
      );
    case _InputStyle2['default'].Hidden:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(_react2['default'].createElement(_antd.Input, _extends({
          disabled: true,
          placeholder: field.PlaceHolder,
          style: { display: 'none' }
        }, inputProps)))
      );
    case _InputStyle2['default'].MoneyInput:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        _react2['default'].createElement(
          'div',
          { hidden: !field.DisplayOnly },
          '$ ' + defaultValue
        ),
        _react2['default'].createElement(
          'div',
          { hidden: field.DisplayOnly },
          getFieldDecorator(field.Column, {
            initialValue: defaultValue
          })(_react2['default'].createElement(_MoneyInput2['default'], _extends({ style: { width: '100%' }, placeholder: field.PlaceHolder }, inputProps)))
        )
      );
    case _InputStyle2['default'].DisplayOnly:
      defaultValue = data ? data[field.Column] : field.DefaultValue;
      return _react2['default'].createElement(
        _antd.Form.Item,
        { key: field.Id, label: field.Label, help: field.Help },
        getFieldDecorator(field.Column, {
          initialValue: defaultValue
        })(_react2['default'].createElement(_antd.Input, _extends({
          disabled: true,
          className: 'formcore_display-only-input',
          style: { width: '100%' },
          placeholder: field.PlaceHolder
        }, inputProps)))
      );
    default:
      if (renderExtra) {
        return renderExtra(field, form, data, inputProps);
      }
      throw new Error('FormCore: Unspported input style ' + field.InputStyle + ' of field ' + field.Id + '. You might want to consider using customized input styles, cf. the renderExtra parameter. Otheriwse pull Requests are welcome: https://github.com/pmq20/FormCore/pulls');
  }
}
module.exports = exports['default'];